@@ -17,10 +17,11 @@ test_dir = os.path.dirname(os.path.realpath(__file__))
 sys.path.insert(0, lib_dir)
 
 from docopt import DocoptExit
-from pontoon import (PontoonException, APIException, DropletException,
+from pontoon import (PontoonException, DropletException,
                      SnapshotException, ConfigureException,
-                     SSHKeyException, ImageException, RegionException,
-                     SizeException, EventException)
+                     SSHKeyException, ImageException,
+                     RegionException, SizeException,
+                     EventException)
 from pontoon import Pontoon
 from pontoon import Command
 from pontoon import ClientException
@@ -538,7 +539,7 @@ class TestConfigure:
         _Popen.side_effect = ["/usr/bin/ssh-keygen", "/usr/bin/openssl"]
         assert configure.ssh_tools() is True
 
-        _Popen.side_effect = lambda cmd, stdout: (
+        _Popen.side_effect = lambda *args, **kwargs: (
             _raise(CalledProcessError("foo", "bar")))
         assert configure.ssh_tools() is False
 
